@@ -6,9 +6,9 @@ Type annotations for qldb service literal definitions.
 Usage::
 
     ```python
-    from mypy_boto3_qldb.literals import ErrorCauseType
+    from mypy_boto3_qldb.literals import EncryptionStatusType
 
-    data: ErrorCauseType = "IAM_PERMISSION_REVOKED"
+    data: EncryptionStatusType = "ENABLED"
     ```
 """
 import sys
@@ -20,6 +20,7 @@ else:
 
 
 __all__ = (
+    "EncryptionStatusType",
     "ErrorCauseType",
     "ExportStatusType",
     "LedgerStateType",
@@ -29,6 +30,7 @@ __all__ = (
 )
 
 
+EncryptionStatusType = Literal["ENABLED", "KMS_KEY_INACCESSIBLE", "UPDATING"]
 ErrorCauseType = Literal["IAM_PERMISSION_REVOKED", "KINESIS_STREAM_NOT_FOUND"]
 ExportStatusType = Literal["CANCELLED", "COMPLETED", "IN_PROGRESS"]
 LedgerStateType = Literal["ACTIVE", "CREATING", "DELETED", "DELETING"]
